]> granicus.if.org Git - mutt/commitdiff
Prefer "backtick" over "backtic" on comments and docs as it's more common, closes...
authorRocco Rutte <pdmef@gmx.net>
Mon, 11 Aug 2008 14:42:06 +0000 (16:42 +0200)
committerRocco Rutte <pdmef@gmx.net>
Mon, 11 Aug 2008 14:42:06 +0000 (16:42 +0200)
ChangeLog
alias.c
doc/manual.xml.head
init.c

index b267c1912304ef378ab25e76a6cd97274ffb6749..8023351c38f16bb035a83c63b7ef0531553948ab 100644 (file)
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,12 @@
+2008-07-27 10:48 -0400  Aron Griffis  <agriffis@n01se.net>  (3f595d14a285)
+
+       * doc/manual.xml.head: doc: semi-colon needs quoting too
+
+       If semi-colon is bound or macro'd, it needs to be quoted like space,
+       otherwise mutt thinks it's separating commands.
+
+       Signed-off-by: Aron Griffis <agriffis@n01se.net>
+
 2008-07-21 10:24 -0400  Aron Griffis  <agriffis@n01se.net>  (96b0dd25a550)
 
        * copy.h, mutt.h: noop cleanup: move mutt_copy_header flags to copy.h
diff --git a/init.c b/init.c
index 3e5327f2a081b5398854d80fcf99acf681ae93ce..6db5a20da3125aad4a36e3ad706f5904f9d29a84 100644 (file)
--- a/init.c
+++ b/init.c
@@ -236,7 +236,7 @@ int mutt_extract_token (BUFFER *dest, BUFFER *tok, int flags)
       } while (pc && *pc != '`');
       if (!pc)
       {
-       dprint (1, (debugfile, "mutt_get_token: mismatched backtics\n"));
+       dprint (1, (debugfile, "mutt_get_token: mismatched backticks\n"));
        return (-1);
       }
       cmd = mutt_substrdup (tok->dptr, pc);
diff --git a/alias.c b/alias.c
index 75d49aa3d2989dd6c891e5d1f0aee6593c08bc01..623dd69718492e2e6f259c4df4c1c57ab88594e3 100644 (file)
--- a/alias.c
+++ b/alias.c
@@ -148,9 +148,9 @@ void mutt_expand_aliases_env (ENVELOPE *env)
  * if someone has an address like
  *     From: Michael `/bin/rm -f ~` Elkins <me@mutt.org>
  * and the user creates an alias for this, Mutt could wind up executing
* the backtics because it writes aliases like
  *     alias me Michael `/bin/rm -f ~` Elkins <me@mutt.org>
* To avoid this problem, use a backslash (\) to quote any backtics.  We also
  * need to quote backslashes as well, since you could defeat the above by
  * doing
  *     From: Michael \`/bin/rm -f ~\` Elkins <me@mutt.org>
index b5c31e55da2a8a408d505ad762b5360298a2f8ad..f0c305d184582bac4ac5bd5f59393811ee957799 100644 (file)
@@ -1351,7 +1351,7 @@ the two types of quotes is similar to that of many popular shell programs,
 namely that a single quote is used to specify a literal string (one that is
 not interpreted for shell variables or quoting with a backslash &lsqb;see
 next paragraph&rsqb;), while double quotes indicate a string for which
-should be evaluated.  For example, backtics are evaluated inside of double
+should be evaluated.  For example, backticks are evaluated inside of double
 quotes, but <emphasis role="bold">not</emphasis> for single quotes.
 </para>
 
@@ -148,9 +148,9 @@ void mutt_expand_aliases_env (ENVELOPE *env)
  *     From: Michael `/bin/rm -f ~` Elkins <me@mutt.org>
  * and the user creates an alias for this, Mutt could wind up executing
- * the backtics because it writes aliases like
+ * the backticks because it writes aliases like
  *     alias me Michael `/bin/rm -f ~` Elkins <me@mutt.org>
@@ -148,9 +148,9 @@ void mutt_expand_aliases_env (ENVELOPE *env)
  *     alias me Michael `/bin/rm -f ~` Elkins <me@mutt.org>
- * To avoid this problem, use a backslash (\) to quote any backtics.  We also
+ * To avoid this problem, use a backslash (\) to quote any backticks.  We also
  * need to quote backslashes as well, since you could defeat the above by
  * doing